# Changelog

## Current (in progress)

- Initial release
- Replace mongo legacy image in CI [#2](https://github.com/etalab/udata-event-consumer/pull/2)
- Update message schemas [#3](https://github.com/etalab/udata-event-consumer/pull/3)
